/// <reference types="google.maps" />
/**
 * Interface with WebRTC-streamer API
 */
import type { HtmlMapMarkerOptions } from '../types';
declare class HtmlMapMarker extends google.maps.OverlayView {
    /**
     * marker position
     * @private
     */
    private readonly latLng;
    /**
     * marker content
     * @private
     */
    private readonly html;
    /**
     * map instance
     * @private
     */
    private readonly map;
    /**
     * marker width
     * @private
     */
    private width;
    /**
     * marker height
     * @private
     */
    private height;
    /**
     * div for marker content
     * @private
     */
    private div?;
    /**
     * Instantiate object
     * accepts latLng, html, map etc
     * @constructor
     * @param args
     */
    constructor(args: HtmlMapMarkerOptions);
    /**
     * create a div to hold the marker content
     */
    createDiv(): void;
    /**
     * position the marker div
     */
    positionDiv(): void;
    /**
     * add the marker div to the map
     */
    onAdd(): void;
    /**
     * reposition the marker div
     */
    draw(): void;
    /**
     * remove the marker div from the map
     */
    onRemove(): void;
    /**
     * get the marker position
     */
    getPosition(): google.maps.LatLng;
    /**
     * remove the marker from the map
     */
    detach(): void;
    /**
     * attach the marker to the map
     * @param map
     */
    attach(map?: google.maps.Map): void;
    /**
     * set size of the marker div
     * @param width
     * @param height
     */
    setSize(width: number, height: number): void;
}
export { HtmlMapMarker };
