import type { WebRTCStreamerOptions } from '../types';
/**
 * Interface with WebRTC-streamer API
 */
declare class WebRTCStreamer {
    private element?;
    private options;
    private peerConnection;
    private peerConnectionConfig?;
    private peerConnectionId;
    private mediaConstraints;
    private iceServers;
    private earlyCandidates;
    /**
     * Instantiate object
     * @constructor
     * @param args
     */
    constructor(args?: Partial<WebRTCStreamerOptions>);
    /**
     * Connect a WebRTC Stream to videoElement
     * @param videUrl
     * @param audioUrl
     * @param options
     * @param localStream
     * @param preferenceMime
     */
    connect(videUrl: string, audioUrl: string, options: string, localStream?: MediaStream, preferenceMime?: string): void;
    /**
     * Disconnect a WebRTC Stream and clear videoElement source
     */
    disconnect(): void;
    private changeElement;
    private handleHttpErrors;
    /**
     * GetIceServers callback
     * @param iceServers
     * @param videoUrl
     * @param audioUrl
     * @param options
     * @param stream
     * @private
     */
    private onReceiveGetIceServers;
    /**
     * AJAX callback for Error
     * @param status
     * @private
     */
    private onError;
    /**
     * create RTCPeerConnection
     * @private
     */
    private createPeerConnection;
    /**
     * AJAX /call callback
     * @param dataJson
     * @private
     */
    private onReceiveCall;
    private addIceCandidate;
    private getIceCandidate;
    /**
     * AJAX /getIceCandidate callback
     * @param dataJson
     * @private
     */
    private onReceiveCandidate;
    /**
     * RTCPeerConnection AddTrack callback
     * @param event
     * @private
     */
    private onAddStream;
    /**
     * RTCPeerConnection IceCandidate callback
     * @param event
     * @private
     */
    private onIceCandidate;
}
export { WebRTCStreamer };
